==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressClassSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class IngressClassSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<A>{
  public IngressClassSpecFluentImpl() {
  }
  public IngressClassSpecFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance) {
    this.withController(instance.getController()); 
    this.withParameters(instance.getParameters()); 
  }
  private java.lang.String controller;
  private io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder parameters;
  public java.lang.String getController() {
    return this.controller;
  }
  public A withController(java.lang.String controller) {
    this.controller=controller; return (A) this;
  }
  public java.lang.Boolean hasController() {
    return this.controller != null;
  }
  
  /**
   * Method is deprecated. use withController instead.
   */
  @java.lang.Deprecated
  public A withNewController(java.lang.String arg0) {
    return (A)withController(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildParameters instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference getParameters() {
    return this.parameters!=null?this.parameters.build():null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference buildParameters() {
    return this.parameters!=null?this.parameters.build():null;
  }
  public A withParameters(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference parameters) {
    _visitables.get("parameters").remove(this.parameters);
    if (parameters!=null){ this.parameters= new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder(parameters); _visitables.get("parameters").add(this.parameters);} return (A) this;
  }
  public java.lang.Boolean hasParameters() {
    return this.parameters != null;
  }
  public A withNewParameters(java.lang.String apiGroup,java.lang.String kind,java.lang.String name,java.lang.String namespace,java.lang.String scope) {
    return (A)withParameters(new IngressClassParametersReference(apiGroup, kind, name, namespace, scope));
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> withNewParameters() {
    return new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluentImpl.ParametersNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> withNewParametersLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item) {
    return new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluentImpl.ParametersNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editParameters() {
    return withNewParametersLike(getParameters());
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editOrNewParameters() {
    return withNewParametersLike(getParameters() != null ? getParameters(): new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editOrNewParametersLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item) {
    return withNewParametersLike(getParameters() != null ? getParameters(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressClassSpecFluentImpl that = (IngressClassSpecFluentImpl) o;
    if (controller != null ? !controller.equals(that.controller) :that.controller != null) return false;
    if (parameters != null ? !parameters.equals(that.parameters) :that.parameters != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(controller,  parameters,  super.hashCode());
  }
  public class ParametersNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ParametersNestedImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder(this, item);
    }
    ParametersNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder builder;
    public N and() {
      return (N) IngressClassSpecFluentImpl.this.withParameters(builder.build());
    }
    public N endParameters() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-networking-5.10.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressClassSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IngressClassSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<A>{
  public IngressClassSpecFluentImpl() {
  }
  public IngressClassSpecFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance) {
    this.withController(instance.getController()); 
    this.withParameters(instance.getParameters()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String controller;
  private io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder parameters;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getController() {
    return this.controller;
  }
  public A withController(java.lang.String controller) {
    this.controller=controller; return (A) this;
  }
  public java.lang.Boolean hasController() {
    return this.controller != null;
  }
  
  /**
   * Method is deprecated. use withController instead.
   */
  @java.lang.Deprecated
  public A withNewController(java.lang.String arg0) {
    return (A)withController(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildParameters instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference getParameters() {
    return this.parameters!=null?this.parameters.build():null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference buildParameters() {
    return this.parameters!=null?this.parameters.build():null;
  }
  public A withParameters(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference parameters) {
    _visitables.get("parameters").remove(this.parameters);
    if (parameters!=null){ this.parameters= new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder(parameters); _visitables.get("parameters").add(this.parameters);} return (A) this;
  }
  public java.lang.Boolean hasParameters() {
    return this.parameters != null;
  }
  public A withNewParameters(java.lang.String apiGroup,java.lang.String kind,java.lang.String name,java.lang.String namespace,java.lang.String scope) {
    return (A)withParameters(new IngressClassParametersReference(apiGroup, kind, name, namespace, scope));
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> withNewParameters() {
    return new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluentImpl.ParametersNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> withNewParametersLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item) {
    return new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluentImpl.ParametersNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editParameters() {
    return withNewParametersLike(getParameters());
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editOrNewParameters() {
    return withNewParametersLike(getParameters() != null ? getParameters(): new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<A> editOrNewParametersLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item) {
    return withNewParametersLike(getParameters() != null ? getParameters(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressClassSpecFluentImpl that = (IngressClassSpecFluentImpl) o;
    if (controller != null ? !controller.equals(that.controller) :that.controller != null) return false;
    if (parameters != null ? !parameters.equals(that.parameters) :that.parameters != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(controller,  parameters,  additionalProperties,  super.hashCode());
  }
  public class ParametersNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent.ParametersNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ParametersNestedImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder(this, item);
    }
    ParametersNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassParametersReferenceBuilder builder;
    public N and() {
      return (N) IngressClassSpecFluentImpl.this.withParameters(builder.build());
    }
    public N endParameters() {
      return and();
    }
    
  }
  
}
